@@ -1,7 +1,8 @@
 import enum
 import json
+from .schemas import BaseSchema
 from pydantic import BaseModel
-from typing import Any, Callable, Iterable, Mapping, Optional, Tuple, Union
+from typing import Any, Callable, Dict, Iterable, Mapping, Optional, Tuple, Union
 from werkzeug.wrappers.response import Response as ResponseBase
 
 class SwaggerJSONEncoder(json.JSONEncoder):
@@ -82,3 +83,31 @@ class PlainTextResponse(ResponseBase):
     ) -> None:
         response = str(response) if response != None else None
         super().__init__(response, status_code, headers, mimetype="text/plain")
+
+
+def response_json_example(
+    schema_object: Optional[Union[Dict[str, Any], BaseSchema, BaseModel, BaseModel.__class__]] = {},
+    example_object: Optional[Union[Dict[str, Any], BaseSchema, BaseModel]] = {},
+):
+    if isinstance(schema_object, (BaseModel.__class__, BaseModel, BaseSchema)):
+        schema_dict = schema_object.schema()
+    else:
+        schema_dict = schema_object
+
+    if not example_object:
+        example_object = schema_object
+
+    if isinstance(example_object, (BaseModel, BaseSchema)):
+        example_dict = example_object.dict()
+    else:
+        example_dict = example_object
+
+    response_structure = {"content": {"application/json": {}}}
+
+    if schema_dict:
+        response_structure["content"]["application/json"]["schema"] = schema_dict
+
+    if example_dict:
+        response_structure["content"]["application/json"]["example"] = example_dict
+
+    return response_structure
