@@ -1,6 +1,7 @@
 from pydantic import BaseModel, create_model
-from pydantic.main import ModelMetaclass
-from typing import Any, Union, Dict
+from typing import Any
+
+from .responses import response_json_example
 
 class BaseSchema(BaseModel):
     def __init__(__pydantic_self__, **data: Any) -> None:
@@ -30,25 +31,10 @@ class BaseSchema(BaseModel):
             newDatas[key] = data
         return newDatas
 
+    def as_response(self):
+        """
+        convert schema to be a response example and schema
+        """
+        return response_json_example(self)
+
 json_model = create_model
-
-def create_response_example(schema_object: Union[Dict[str, Any], BaseSchema]):
-    if isinstance(schema_object, (BaseModel.__class__, BaseModel, BaseSchema)):
-        schema_dict = schema_object.schema()
-    else:
-        schema_dict = schema_object
-
-    if isinstance(schema_object, (BaseModel, BaseSchema)):
-        example_dict = schema_object.dict()
-    else:
-        example_dict = schema_object
-
-    response_structure = {"content": {"application/json": {}}}
-
-    if schema_dict:
-        response_structure["content"]["application/json"]["schema"] = schema_dict
-
-    if example_dict:
-        response_structure["content"]["application/json"]["example"] = example_dict
-
-    return response_structure
